Erstellen eines dynamischen Routenservers

Der Dynamic Route Server for VPC ist eine Beta-Funktion, die ausgewählten Kunden zu Evaluierungs- und Testzwecken zur Verfügung steht. Der Zugriff ist auf Konten beschränkt, die auf der Whitelist stehen.

Sie können einen dynamischen Routingserver einrichten, um ein richtliniengesteuertes, dynamisches Routing zwischen Ihrer VPC und verbundenen Netzwerken zu ermöglichen, indem Sie mithilfe von BGP Routen mit externen Peers austauschen. Sie können einem dynamischen Routingserver Mitglieder hinzufügen, um Routing-Appliances über Verfügbarkeitszonen hinweg bereitzustellen und so eine hohe Verfügbarkeit und Ausfallsicherheit für den BGP-Routenaustausch zu gewährleisten.

Eine Instanz eines dynamischen Routing-Servers enthält ein oder mehrere Mitglieder und definiert den Routing-Bereich für Peers und Richtlinien. Ein Member ist ein Routing-Gerät, das als virtuelle Serverinstanz bereitgestellt wird und den BGP-Routing-Stack ausführt. Die Mitglieder bauen BGP-Sitzungen mit Peers auf. Eine dynamische Routing-Server-Instanz kann zur Gewährleistung der Hochverfügbarkeit ein bis drei Mitglieder umfassen.

Vorbereitende Schritte

Bevor Sie einen dynamischen Routingserver erstellen:

Erstellen eines dynamischen Routing-Servers in der Konsole

Um einen dynamischen Routingserver in der Konsole zu erstellen, führen Sie die folgenden Schritte aus:

  1. Öffnen Sie in Ihrem Browser die IBM Cloud-Konsole und melden Sie sich bei Ihrem Konto an.
  2. Wählen Sie das Symbol für das Navigationsmenü aus und klicken Sie anschließend auf das Symbol Infrastruktur VPC > Netzwerk > Dynamische Routenserver.
  3. Klicken Sie auf der Seite Dynamische Routenserver für VPC auf Erstellen.
  4. Geben Sie die folgenden Informationen an:
    • Standort – Wählen Sie den Standort aus, an dem der dynamische Routingserver bereitgestellt wird.
    • Name – Geben Sie einen Namen für den dynamischen Routenserver ein, z. B. my-dynamic-route-server.
    • Ressourcengruppe – Wählen Sie eine Ressourcengruppe für den dynamischen Routenserver aus.
    • Tags – Fügen Sie optional Tags hinzu, um diesen dynamischen Routenserver zu identifizieren.
    • Zugriffsverwaltungs-Tags – Optional können Sie Ressourcen mit Zugriffsverwaltungs-Tags versehen, um die Beziehungen bei der Zugriffskontrolle besser zu organisieren. Das einzige unterstützte Format für Zugriffsverwaltungstags ist key:value. Weitere Informationen finden Sie unter Zugriff auf Ressourcen mithilfe von Tags steuern.
    • Virtuelle private Cloud – Wählen Sie die VPC für den dynamischen Routingserver aus.
    • ASN – Geben Sie einen ASN-Wert ein. Ein ASN ist eine numerische Kennung für den dynamischen Routenserver, die Ihr lokales Netzwerk für das BGP-Peering identifiziert und zum Aufbau einer BGP-Sitzung mit anderen Peers verwendet wird.
  5. Erstellen Sie ein dynamisches Routenserver-Element und klicken Sie im Bereich Zusammenfassung auf Dynamischen Routenserver erstellen.

Erstellen von dynamischen Routenserver-Mitgliedern

Um in der Konsole ein dynamisches Routen-Server-Element zu erstellen, führen Sie die folgenden Schritte aus:

  1. Klicken Sie im Abschnitt Mitglieder des dynamischen Routingservers auf Erstellen. Mitglieder des dynamischen Routenservers benötigen eine virtuelle Netzwerkschnittstelle (VNI), um BGP-Sitzungen aufzubauen. Sie können eine vorhandene VNI anhängen oder eine neue erstellen. Weitere Informationen finden Sie unter Über virtuelle Netzwerkschnittstellen.
  2. Geben Sie einen Namen für das Mitglied des dynamischen Routenservers ein, z. B. my-drs-mem.
  3. Wählen Sie den Standort aus, an dem das Mitglied angelegt wird.
  4. Wenn Sie bereits über eine VNI verfügen, wählen Sie eine aus der Liste aus. Falls Sie noch kein Konto haben, befolgen Sie diese Schritte:
    • Klicken Sie im Abschnitt Details auf Erstellen und geben Sie einen Namen für die virtuelle Netzwerkschnittstelle ein.
      • Wählen Sie die Ressourcengruppe aus, zu der sie gehört.
      • Wählen Sie das Subnetz aus, das Sie für das Mitglied verwenden möchten.
      • Fügen Sie die Netzwerk- und IP-Informationen hinzu
      • Klicken Sie auf Weiter
    • Geben Sie im Abschnitt Netzwerkkonfiguration die folgenden Informationen ein:
      • IP-Spoofing zulassen: Wählen Sie den Schalter aus, um IP-Spoofing zu deaktivieren.

      • Infrastruktur-NAT: Wählen Sie den Schalter aus, um Infrastruktur-NAT zu aktivieren.

        Infrastruktur-NAT ist aktiviert, wenn IP-Spoofing aktiviert ist, und muss für das Mitglied des dynamischen Routen-Servers aktiviert sein.

      • Filtermodus für den Protokollstatus: Wählen Sie ein Optionsfeld aus, um den Modus festzulegen. Für den dynamischen Routingserver muss die Einstellung auf Auto oder Aktiviert gesetzt sein.

      • Sicherheitsgruppen: Wählen Sie mindestens eine und höchstens fünf Sicherheitsgruppen aus, um den Datenverkehr auf Netzwerkebene zu steuern. Sie können Sicherheitsgruppen aus der Liste auswählen oder eine neue erstellen, indem Sie auf Erstellen klicken. Weitere Informationen zum Erstellen einer Sicherheitsgruppe finden Sie unter Sicherheitsgruppen erstellen.

    • Behalten Sie im Abschnitt IP die Standardeinstellung bei. Ein VNI eines dynamischen Routenserver-Mitglieds muss über eine primäre IP-Adresse verfügen.
    • Überprüfen Sie die Informationen im Bereich Zusammenfassung und klicken Sie auf Erstellen.

Erstellen eines dynamischen Routing-Servers über die Befehlszeile

Um einen dynamischen Routingserver über die Befehlszeile (CLI) zu erstellen, führen Sie die folgenden Schritte aus:

  1. Konfigurieren Sie die Umgebung der Befehlszeilenschnittstelle.

  2. Melden Sie sich bei Ihrer CLI-Umgebung an. Nach der Eingabe des Kennworts werden Sie vom System aufgefordert, anzugeben, welches Konto und welche Region verwendet werden soll:

    ibmcloud login --sso
    
  3. Aktivieren Sie das folgende Feature-Flag:

    export IBMCLOUD_IS_FEATURE_DYNAMIC_ROUTE_SERVER=true
    
  4. Führen Sie den folgenden Befehl aus:

    ibmcloud is dynamic-route-server-create --local-asn LOCAL_ASN (--members MEMBERS_JSON | @MEMBERS_JSON_FILE) [--name NAME] [--resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME] [--output JSON] [-q, --quiet]
    

Dabei gilt:

--local-asn : Die Nummer des lokalen autonomen Systems (ASN).

--members : Eine JSON-Nutzlast, die die Mitglieder des dynamischen Routenservers definiert. Sie können mindestens ein und höchstens drei Mitglieder angeben. Informationen zum Datenschema finden Sie unter der Eigenschaft members in der API-Dokumentation.

@MEMBERS_JSON_FILE : Eine Datei, die die JSON-Daten der Mitglieder enthält.

--name : Der Name des dynamischen Routenservers.

--resource-group-id : Die ID der Ressourcengruppe. Diese Option schließt die andere Option aus --resource-group-name.

--resource-group-name : Der Name der Ressourcengruppe. Diese Option schließt die andere Option aus --resource-group-id.

--output : Ausgabe im JSON-Format.

-q, --quiet : Unterdrückt ausführliche Ausgaben.

Um über die Befehlszeile ein dynamisches Routing-Server-Element zu erstellen, führen Sie den folgenden Befehl aus:

ibmcloud is dynamic-route-server-member-create DYNAMIC_ROUTE_SERVER (--vni VNI | (--vni-auto-delete true | false [--vni-psfm auto | enabled | disabled] --vni-name VNI_NAME [--vni-rip VNI_RIP | (--vni-rip-address VNI_RIP_ADDRESS --vni-rip-auto-delete true | false --vni-rip-name VNI_RIP_NAME)] --vni-subnet VNI_SUBNET [--vpc VPC] --vni-sgs VNI_SGS --vni-ais false | true --vni-ein true | false --vni-ips VNI_RESERVED_IPS_JSON | @VNI_RESERVED_IPS_JSON_FILE --resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME)) [--name NAME] [--output JSON] [-q, --quiet]

Dabei gilt:

Die Kennung DYNAMIC_ROUTE_SERVER : des dynamischen Routenservers.

--vni : Die ID oder der Name des VNI.

--vni-auto-delete : Gibt an, ob die VNI automatisch gelöscht wird, wenn ihr Ziel gelöscht wird. Entweder: true oder false.

--vni-psfm : Der Filtermodus für den Protokollstatus des VNI. Je auto nach target Ressourcentyp des VNI wird die Protokollstatus-Paketfilterung aktiviert oder deaktiviert. Entweder: auto, enabled, oder disabled. Die Standardeinstellung ist auto.

--vni-name : Der Name des VNI.

--vni-rip : Die ID oder der Name der reservierten IP-Adresse, die an die VNI gebunden werden soll. Erforderlich, wenn Sie kein Subnetz angeben.

--vni-rip-address : Die IP-Adresse der reservierten IP, die an die VNI gebunden werden soll. Erfordert ein Subnetz.

--vni-rip-auto-delete : Gibt an, ob die reservierte IP-Adresse automatisch gelöscht wird, wenn ihr Ziel gelöscht wird oder wenn die Bindung der reservierten IP-Adresse aufgehoben wird. Entweder: true oder false.

--vni-rip-name : Der Name der reservierten IP-Adresse, die an die VNI gebunden werden soll.

--vni-subnet : Die ID oder der Name des Subnetzes. Wenn Sie einen Namen angeben, verwenden Sie zur --vpc Angabe der VPC für die Namensauflösung.

--vpc : Die ID oder der Name der VPC. Erforderlich für die Namensauflösung von Subnetzen.

--vni-sgs : Eine durch Kommas getrennte Liste der IDs oder Namen der Sicherheitsgruppen für die VNI.

IP-Spoofing --vni-ais : zulassen. Gibt an, ob Source-IP-Spoofing auf dem VNI zulässig ist. Entweder: false oder true. Der Standardwert ist false.

--vni-ein : Aktivieren Sie NAT für die Infrastruktur. Gibt an, ob die VPC-Infrastruktur erforderliche NAT-Vorgänge durchführt. Entweder: true oder false. Der Standardwert ist true.

--vni-ips : Eine JSON-Nutzlast, die die sekundären reservierten IP-Adressen definiert, die an die VNI gebunden werden sollen.

@VNI_RESERVED_IPS_JSON_FILE : Eine Datei, die die JSON-Daten der sekundär reservierten IP-Adressen enthält.

--resource-group-id : Die ID der Ressourcengruppe. Diese Option schließt die andere Option aus --resource-group-name.

--resource-group-name : Der Name der Ressourcengruppe. Diese Option schließt die andere Option aus --resource-group-id.

--name : Der Name des Mitglieds des dynamischen Routenservers.

--output : Ausgabe im JSON-Format.

-q, --quiet : Unterdrückt ausführliche Ausgaben.

Befehlsbeispiele

  • Um einen dynamischen Routingserver mit lokalem ASN und einem Mitglied zu erstellen, führen Sie den folgenden Befehl aus:

    ibmcloud is dynamic-route-server-create --local-asn 64514 --members '[{"name":"drs-member-1","virtual_network_interfaces":[{"id":"0717-3c8a9f81-b1a0-4c92-9a38-1d9c2f9d1234"}]}]' --name my-dynamic-route-server --resource-group-name default --output JSON
    
  • Um ein dynamisches Routen-Server-Element zu erstellen, führen Sie den folgenden Befehl aus:

    ibmcloud is dynamic-route-server-member-create 0717-drs-12345678 --vni-auto-delete false --vni-psfm auto --vni-name drs-member-vni-1 --vni-rip-address 10.0.1.5 --vni-rip-auto-delete false --vni-rip-name drs-member-rip-1 --vni-subnet 0717-subnet-abc12345 --vpc 0717-vpc-9f8e7d6c --vni-sgs 0717-sg-111aaa22,0717-sg-333bbb44 --vni-ais false --vni-ein true --resource-group-name default --name drs-member-2 --output JSON
    

Erstellen eines dynamischen Routing-Servers mit der API

Um einen dynamischen Routenserver mit der API zu erstellen, führen Sie die folgenden Schritte aus:

  1. Richten Sie Ihre API-Umgebung mit den erforderlichen Variablen ein.

  2. Speichern Sie alle zusätzlichen Variablen, die in den API-Befehlen verwendet werden sollen. Zum Beispiel:

    • ResourceGroupId - Suchen Sie die Ressourcengruppen-ID mithilfe des Befehls get resource groups und füllen Sie dann die Variable:
    export ResourceGroupId=<your_resourcegroup_id>
    
  3. Wenn alle Variablen festgelegt sind, erstellen Sie den dynamischen Routingserver:

    curl -X POST \
      "$vpc_api_endpoint/v1/dynamic_route_servers?version=$api_version&generation=2" \
      -H "Authorization: Bearer $iam_token" \
      -H "Content-Type: application/json" \
      -d '{
        "name": "my-drs",
        "local_asn": 64514,
        "members": [
          {
            "name": "my-drs-member",
            "virtual_network_interfaces": [
              {
                "id": "VNI_ID"
              }
            ]
          }
        ],
        "resource_group": {
          "id": "abcd1234-5678"
        }
      }'
    

Nächste Schritte

Nachdem Ihr dynamischer Routenserver nun bereitgestellt ist, sollten Sie die folgenden Schritte in Betracht ziehen: